@@ -19,35 +19,34 @@ headers = {"Authorization": "token " + os.getenv("ACCESS_TOKEN", "")}
 def load_pickle_string(s):  # pragma: no cover
     return pickle.loads(codecs.decode(s.encode(), "base64"))
 
-
+#
 def parse_hidden(output):
     final_output=[]
-    # for out in [y["data"] for y in output["outputs"]]:
+    for out in [y["data"] for y in output["outputs"]]:
     
-    #     if type(out) == str and out.startswith("lookup:"):
-    #         # Get the binary data
-    #         l_split = out.split("lookup:")
+        if type(out) == str and out.startswith("lookup:"):
+            # Get the binary data
+            l_split = out.split("lookup:")
 
-    #         r = requests.get(
-    #             sandy_base_url + "/pickle?lookup=" + l_split[1], headers=headers
-    #         )
-
-    #         out = load_pickle_string(r.content.decode())
-    #         final_output.append(out)
-    #     else:
-    #         final_output.append(out)
-    print(output)
-    for y in output:
-        try:
-            id = y['id']
             r = requests.get(
-                sandy_base_url + "/pickle?lookup=" + id, headers=headers
+                sandy_base_url + "/pickle?lookup=" + l_split[1], headers=headers
             )
 
             out = load_pickle_string(r.content.decode())
             final_output.append(out)
-        except:
-            final_output.append(y)
+        else:
+            final_output.append(out)
+    # for y in output:
+    #     try:
+    #         id = y['id']
+    #         r = requests.get(
+    #             sandy_base_url + "/pickle?lookup=" + id, headers=headers
+    #         )
+
+    #         out = load_pickle_string(r.content.decode())
+    #         final_output.append(out)
+    #     except:
+    #         final_output.append(y)
 
 
     return final_output
